==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkNetCDFCFReader.java <==
// java wrapper for vtkNetCDFCFReader object
//

package vtk;
import vtk.*;

public class vtkNetCDFCFReader extends vtkNetCDFReader
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetSphericalCoordinates_2();
  public int GetSphericalCoordinates()
    { return GetSphericalCoordinates_2(); }

  private native void SetSphericalCoordinates_3(int id0);
  public void SetSphericalCoordinates(int id0)
    { SetSphericalCoordinates_3(id0); }

  private native void SphericalCoordinatesOn_4();
  public void SphericalCoordinatesOn()
    { SphericalCoordinatesOn_4(); }

  private native void SphericalCoordinatesOff_5();
  public void SphericalCoordinatesOff()
    { SphericalCoordinatesOff_5(); }

  private native double GetVerticalScale_6();
  public double GetVerticalScale()
    { return GetVerticalScale_6(); }

  private native void SetVerticalScale_7(double id0);
  public void SetVerticalScale(double id0)
    { SetVerticalScale_7(id0); }

  private native double GetVerticalBias_8();
  public double GetVerticalBias()
    { return GetVerticalBias_8(); }

  private native void SetVerticalBias_9(double id0);
  public void SetVerticalBias(double id0)
    { SetVerticalBias_9(id0); }

  private native int GetOutputType_10();
  public int GetOutputType()
    { return GetOutputType_10(); }

  private native void SetOutputType_11(int id0);
  public void SetOutputType(int id0)
    { SetOutputType_11(id0); }

  private native void SetOutputTypeToAutomatic_12();
  public void SetOutputTypeToAutomatic()
    { SetOutputTypeToAutomatic_12(); }

  private native void SetOutputTypeToImage_13();
  public void SetOutputTypeToImage()
    { SetOutputTypeToImage_13(); }

  private native void SetOutputTypeToRectilinear_14();
  public void SetOutputTypeToRectilinear()
    { SetOutputTypeToRectilinear_14(); }

  private native void SetOutputTypeToStructured_15();
  public void SetOutputTypeToStructured()
    { SetOutputTypeToStructured_15(); }

  private native void SetOutputTypeToUnstructured_16();
  public void SetOutputTypeToUnstructured()
    { SetOutputTypeToUnstructured_16(); }

  private native int CanReadFile_17(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_17(id0); }

  public vtkNetCDFCFReader() { super(); }

  public vtkNetCDFCFReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-1-aarch64.pkg.tar.xz: vtk/vtkNetCDFCFReader.java <==
// java wrapper for vtkNetCDFCFReader object
//

package vtk;
import vtk.*;

public class vtkNetCDFCFReader extends vtkNetCDFReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetSphericalCoordinates_2();
  public int GetSphericalCoordinates()
    { return GetSphericalCoordinates_2(); }

  private native void SetSphericalCoordinates_3(int id0);
  public void SetSphericalCoordinates(int id0)
    { SetSphericalCoordinates_3(id0); }

  private native void SphericalCoordinatesOn_4();
  public void SphericalCoordinatesOn()
    { SphericalCoordinatesOn_4(); }

  private native void SphericalCoordinatesOff_5();
  public void SphericalCoordinatesOff()
    { SphericalCoordinatesOff_5(); }

  private native double GetVerticalScale_6();
  public double GetVerticalScale()
    { return GetVerticalScale_6(); }

  private native void SetVerticalScale_7(double id0);
  public void SetVerticalScale(double id0)
    { SetVerticalScale_7(id0); }

  private native double GetVerticalBias_8();
  public double GetVerticalBias()
    { return GetVerticalBias_8(); }

  private native void SetVerticalBias_9(double id0);
  public void SetVerticalBias(double id0)
    { SetVerticalBias_9(id0); }

  private native int GetOutputType_10();
  public int GetOutputType()
    { return GetOutputType_10(); }

  private native void SetOutputType_11(int id0);
  public void SetOutputType(int id0)
    { SetOutputType_11(id0); }

  private native void SetOutputTypeToAutomatic_12();
  public void SetOutputTypeToAutomatic()
    { SetOutputTypeToAutomatic_12(); }

  private native void SetOutputTypeToImage_13();
  public void SetOutputTypeToImage()
    { SetOutputTypeToImage_13(); }

  private native void SetOutputTypeToRectilinear_14();
  public void SetOutputTypeToRectilinear()
    { SetOutputTypeToRectilinear_14(); }

  private native void SetOutputTypeToStructured_15();
  public void SetOutputTypeToStructured()
    { SetOutputTypeToStructured_15(); }

  private native void SetOutputTypeToUnstructured_16();
  public void SetOutputTypeToUnstructured()
    { SetOutputTypeToUnstructured_16(); }

  private native int CanReadFile_17(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_17(id0); }

  public vtkNetCDFCFReader() { super(); }

  public vtkNetCDFCFReader(long id) { super(id); }
  public native long   VTKInit();

}
